@@ -1,6 +1,6 @@
 package Git::Hooks;
 # ABSTRACT: Framework for implementing Git (and Gerrit) hooks
-$Git::Hooks::VERSION = '1.15.1';
+$Git::Hooks::VERSION = '1.16.0';
 use 5.010;
 use strict;
 use warnings;
@@ -29,9 +29,8 @@ BEGIN {                         ## no critic (RequireArgUnpacking)
         $hook =~ tr/_/-/;
         no strict 'refs';       ## no critic (ProhibitNoStrict)
         *{__PACKAGE__ . '::' . $installer} = sub (&) {
-            my ($foo) = @_;
-            my $subname = subname($foo);
-            $Hooks{$hook}{$subname} ||= sub { $foo->(@_); };
+            my ($sub) = @_;
+            push @{$Hooks{$hook}}, sub { $sub->(@_); };
         }
     }
 
@@ -645,8 +644,8 @@ sub run_hook {                  ## no critic (Subroutines::ProhibitExcessComplex
     my $errors = 0;             # Count number of errors found
 
     # Call every hook function installed by the hook scripts before.
-    while (my ($subname, $hook) = each %{$Hooks{$hook_name}}) {
-        my ($package) = $subname =~ m/^(.+)::/;
+    for my $hook (@{$Hooks{$hook_name}}) {
+        my ($package) = subname($hook) =~ m/^(.+)::/;
         my $ok = eval { $hook->($git, @args) };
         if (defined $ok) {
             # Modern hooks return a boolean value indicating their success.
@@ -728,7 +727,7 @@ Git::Hooks - Framework for implementing Git (and Gerrit) hooks
 
 =head1 VERSION
 
-version 1.15.1
+version 1.16.0
 
 =head1 SYNOPSIS
 
